# Shinkendo

This is a CLI program that can be used to interact with Shinken via Shinken WebUI.

As this is a WIP, many functions are still missing.

Please be aware that this program interacts with Shinken *via the Webui*. So you need a working WebUI v2.7 or more.

## Installation

```
pip install shinkendo
```

## Usage


```
shinkendo --help
```
